@@ -1,18 +1,26 @@
 //! # based
 //!
-//! `based` supports the creation of bases with custom digits,
-//! where each digit is one character. 
+//! `based` provides support for custom numeral systems with single-character digits.
 //!
-//! `based` does not currently support multiple-character digits.
-//!
-
+//! `based` does not currently support multi-character digits.
 
 use std::ops::{AddAssign, MulAssign};
 
 #[derive(Debug)]
-/// Error type produced when [`Base::from_str`](Base::from_str) encounters an unknown character.
-/// Contains the unknown character.
-pub struct UnknownChar(char);
+/// `UnknownChar` is the error type produced when 
+/// [`Base::from_str`](Base::from_str) encounters an unknown character.
+/// It contains the unknown character.
+/// 
+/// # Examples
+/// 
+/// ```
+/// use based::Base;
+///
+/// let base16 = Base::new("0123456789abcdef");
+/// let sixteen = base16.from_str::<usize>("0n1");
+/// assert_eq!(sixteen.err().unwrap().0, 'n');
+/// ```
+pub struct UnknownChar(pub char);
 
 impl std::fmt::Display for UnknownChar {
   fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
@@ -26,7 +34,7 @@ impl std::error::Error for UnknownChar {
   }
 }
 
-/// The base of a numeral system.
+/// `Base` represents a numeral system.
 pub struct Base {
   base: Vec<char>,
   vals: std::collections::HashMap<char, usize>,
@@ -39,13 +47,13 @@ impl std::fmt::Display for Base {
 }
 
 impl Base {
-  /// Creates a new base from the given string slice.
+  /// Creates a new numeral system from the given string slice.
   /// 
   /// The value of each character is its index in the slice,
-  /// e.g. the first character has value 0, the second
-  /// value 1, etc.
+  /// e.g. the first character has value `0`, the second
+  /// value `1`, etc.
   /// 
-  /// The behavior of the function is undefined when
+  /// The behavior of this function is undefined when
   /// a character is present more than once in the given
   /// string slice.
   ///
@@ -76,7 +84,7 @@ impl Base {
   /// Given a base and a number's representation
   /// in that base, return the number.
   ///
-  /// Returns `Err` if it encounters a character not in the `Base`.
+  /// Returns `Err` if this function encounters a character not in the `Base`.
   ///
   /// # Examples
   /// 
